# -*- coding: utf-8 -*- #
# Copyright 2018 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Commands for Compute Engine reservations."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.UniverseCompatible
@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
class Reservations(base.Group):
  """Manage Compute Engine reservations."""
  category = base.COMPUTE_CATEGORY

Reservations.detailed_help = {
    'DESCRIPTION': """
        Manage Compute Engine reservations.

        For more information about reservations, see the
        [reservations documentation](https://cloud.google.com/compute/docs/instances/reserving-zonal-resources).

        See also: [Reservations API](https://cloud.google.com/compute/docs/reference/rest/v1/reservations).
    """,
}
